
#include "../src/comdef.h"
#include "../src/classic.h"
#include "../src/i2c-eeprom.h"
#include "../src/spi-eeprom.h"

#if defined(__TMS470__)|| \
    defined(__TMS320C28XX__)
  #include "../src/int-flash.h"
#endif

void main(void)
{                
  buffer_size = BUF_SIZE;
  status = STATUS_OK;
  fProgKeys = 0;

  while (1) {
                 
/* ------ Emulation STOP ---------
   for CPU's, that doesn't support software breakpoint (ESTOP, e.t.c) 
   assembly instruction simply put global "_BreakPoint" label with 
   NOP instruction to tell TCL script to set hardware breakpoint
   here
*/

#if defined(__TMS320C55X__)
    asm("	estop_1");
#elif defined(__TMS320C28XX__)
    asm("	ESTOP0");
#elif defined(_TMS320C6400_PLUS) || \
      defined(__C6720__)
    asm("	NOP  5");
    asm("  .global _BreakPoint");
    asm("_BreakPoint:  NOP	5");
    asm("	NOP  5");
#elif defined(_TMS320C6X)
    asm("	NOP  5");
    asm("	.long 0x10000000"); // NOP with SWBP in CREG field
    asm("	NOP  5");
#else
    asm("  .global _BreakPoint");
    asm("_BreakPoint:  NOP");
#endif                 

   /* Reset status */
    status = STATUS_OK;

    if (command == CMD_PROGRAM) {

	  /* Aling length to "width" */
	  while (length & (7 >> (3-width))) {
	    PutByte((void*)buffer,length,0xFF);
		length++;
	  }

      /* command = write flash */
	  switch (flash_type) {
	    case I2C_24xx_EEPROM: /* I2C 24xx EEPROM */
          perform_i2c_eeprom_program();
		  break;
		case CLASSIC_NOR_FLASH: /* Classic 8/16bit wide NOR flash*/
          perform_classic_flash_program();
		  break;
	    case SPI_25xx_EEPROM: /* SPI 25xx EEPROM, 25Fxx Flash */
          perform_SPI_eeprom_program();
		  break;

#if defined(__TMS470__)|| \
    defined(__TMS320C28XX__)
	    case INTERNAL_FLASH: /* Internal Flash */
          perform_int_flash_program();
		  break;
#endif

		default:
          status = STATUS_FLASHTYPE_ERR;
	  }
      
      continue;
    }

    if (command == CMD_ERASESECTOR) {
      /* command = erase sector */
	  switch (flash_type) {
	  
	    case I2C_24xx_EEPROM: /* I2C 24xx EEPROM */
          perform_i2c_eeprom_erase();
		  break;
		  
		case CLASSIC_NOR_FLASH: /* Classic 8/16bit wide NOR flash*/
          perform_classic_flash_erase();
		  break;
		  
	    case SPI_25xx_EEPROM: /* SPI 25xx EEPROM, 25Fxx Flash */
          perform_SPI_eeprom_erase();
		  break;

#if defined(__TMS470__)|| \
    defined(__TMS320C28XX__)
	    case INTERNAL_FLASH: /* Internal Flash */
          perform_int_flash_erase();
		  break;
#endif

  		default:
          status = STATUS_FLASHTYPE_ERR;
      }
	  continue;
    }
    
    status = STATUS_BAD_COMMAND;       
  }  
  
}



